==> openshift-model-config-6.0.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ExternalIPPolicyFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface ExternalIPPolicyFluent<A extends ExternalIPPolicyFluent<A>> extends Fluent<A>{
  public A addToAllowedCIDRs(Integer index,String item);
  public A setToAllowedCIDRs(Integer index,String item);
  public A addToAllowedCIDRs(java.lang.String... items);
  public A addAllToAllowedCIDRs(Collection<String> items);
  public A removeFromAllowedCIDRs(java.lang.String... items);
  public A removeAllFromAllowedCIDRs(Collection<String> items);
  public List<String> getAllowedCIDRs();
  public String getAllowedCIDR(Integer index);
  public String getFirstAllowedCIDR();
  public String getLastAllowedCIDR();
  public String getMatchingAllowedCIDR(Predicate<String> predicate);
  public Boolean hasMatchingAllowedCIDR(Predicate<String> predicate);
  public A withAllowedCIDRs(List<String> allowedCIDRs);
  public A withAllowedCIDRs(java.lang.String... allowedCIDRs);
  public Boolean hasAllowedCIDRs();
  public A addToRejectedCIDRs(Integer index,String item);
  public A setToRejectedCIDRs(Integer index,String item);
  public A addToRejectedCIDRs(java.lang.String... items);
  public A addAllToRejectedCIDRs(Collection<String> items);
  public A removeFromRejectedCIDRs(java.lang.String... items);
  public A removeAllFromRejectedCIDRs(Collection<String> items);
  public List<String> getRejectedCIDRs();
  public String getRejectedCIDR(Integer index);
  public String getFirstRejectedCIDR();
  public String getLastRejectedCIDR();
  public String getMatchingRejectedCIDR(Predicate<String> predicate);
  public Boolean hasMatchingRejectedCIDR(Predicate<String> predicate);
  public A withRejectedCIDRs(List<String> rejectedCIDRs);
  public A withRejectedCIDRs(java.lang.String... rejectedCIDRs);
  public Boolean hasRejectedCIDRs();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/ExternalIPPolicyFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ExternalIPPolicyFluent<A extends ExternalIPPolicyFluent<A>> extends Fluent<A>{
  public A addToAllowedCIDRs(int index,String item);
  public A setToAllowedCIDRs(int index,String item);
  public A addToAllowedCIDRs(java.lang.String... items);
  public A addAllToAllowedCIDRs(Collection<String> items);
  public A removeFromAllowedCIDRs(java.lang.String... items);
  public A removeAllFromAllowedCIDRs(Collection<String> items);
  public List<String> getAllowedCIDRs();
  public String getAllowedCIDR(int index);
  public String getFirstAllowedCIDR();
  public String getLastAllowedCIDR();
  public String getMatchingAllowedCIDR(Predicate<String> predicate);
  public Boolean hasMatchingAllowedCIDR(Predicate<String> predicate);
  public A withAllowedCIDRs(List<String> allowedCIDRs);
  public A withAllowedCIDRs(java.lang.String... allowedCIDRs);
  public Boolean hasAllowedCIDRs();
  public A addToRejectedCIDRs(int index,String item);
  public A setToRejectedCIDRs(int index,String item);
  public A addToRejectedCIDRs(java.lang.String... items);
  public A addAllToRejectedCIDRs(Collection<String> items);
  public A removeFromRejectedCIDRs(java.lang.String... items);
  public A removeAllFromRejectedCIDRs(Collection<String> items);
  public List<String> getRejectedCIDRs();
  public String getRejectedCIDR(int index);
  public String getFirstRejectedCIDR();
  public String getLastRejectedCIDR();
  public String getMatchingRejectedCIDR(Predicate<String> predicate);
  public Boolean hasMatchingRejectedCIDR(Predicate<String> predicate);
  public A withRejectedCIDRs(List<String> rejectedCIDRs);
  public A withRejectedCIDRs(java.lang.String... rejectedCIDRs);
  public Boolean hasRejectedCIDRs();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
